#
# spec file for package signify
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           signify
Version:        32
Release:        1.5
Summary:        OpenBSD tool to sign and verify signatures on files (portable version)
License:        BSD-3-Clause
Group:          Productivity/Networking/Security
URL:            https://github.com/aperezdc/signify
Source0:        %{url}/releases/download/v%{version}/signify-%{version}.tar.xz
Source1:        %{url}/releases/download/v%{version}/signify-%{version}.tar.xz.asc
# https://github.com/aperezdc/signify/blob/master/README.md#release-signing
Source2:        %{name}.keyring
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libbsd) >= 0.11.0

%description
Signify - Sign and Verify.
A portable version of the OpenBSD tool to sign and verify signatures on files.
See http://www.tedunangst.com/flak/post/signify for more information.

%prep
%setup -q

%build
export EXTRA_CFLAGS="%{optflags} -D_GNU_SOURCE"
export PREFIX="%{_prefix}"
%make_build

%install
export EXTRA_CFLAGS="%{optflags} -D_GNU_SOURCE"
export PREFIX="%{_prefix}"
%make_install

%check
%make_build check

%files
%license COPYING
%doc README.md CHANGELOG.md
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}

%changelog
* Sun Mar 10 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 32
  Changed
  * Allow overriding the INSTALL Make variable to set the program
    used instead of install.
  * Updated sources from upstream OpenBSD and libbsd 0.12.1
  Fixed
  * Fixed the build with VERIFY_ONLY=1.
* Thu Mar  2 2023 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 31:
  * provides a bundled libbsd (not used in the openSUSE package)
- needs libbsd 0.11.0 for freezero
- run tests
- add upstream signing key and verify source signature
* Wed May 19 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 30
  * Minor build system related changes
* Sat Mar  7 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 29
  * Source packages now include a license.
* Thu Feb  6 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 28
  Added
  * In verification mode (with -C) it is now possible to use the
  - t command line flag to specify the key type.
  * A copy of the regression tests from the OpenBSD CVS repository
    is now included.
  Changed
  * Bumped version of libbsd to 0.10.0, which is the most recent
    stable.
  Fixed
  * Ensure that release packages include the code for the libwaive/
  submodule.
* Mon Nov  4 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 27
  * Updated to the latest upstream sources, the size of a fixed
    buffer has been changed to use `PATH_MAX` instead to avoid
    potential overflows when using very long path names.
* Thu Jul 25 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 26
  * Provide a definition for the `__dead` marker when using GCC 4+
    or Clang.
  * Ensure that the prototype for `asprintf()` gets defined by
    system headers.
  * Silence (harmless) compiler warnings enabled in more recent
    GCC/Clang releases when using `-Wall`.
* Wed May  8 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 25
  * Updated to the latest upstream sources, the `-z` command line flag can
    now be used to zero the timestamp when producing a signature.
- Run spec-cleaner
* Sun Sep 23 2018 AxelKoellhofer@web.de
- updated to version 24
  * Fixed memory corruption due to incorrect remapping of SHA-224, SHA-384,
    and SHA-512-256 to incompatible counterparts in `compat.h`. Thanks to
    Ori Bernstein for the bug report (#17) and Wolfgang Müller for submitting
    the fix (#18).
  * Bumped version of libbsd to 0.9.1 for bundling, which does not need
    patching to work with Musl.
* Sun Dec 10 2017 AxelKoellhofer@web.de
- updated to version 23
  * Fixed handling of the `errno` variable.
* Wed Aug 23 2017 AxelKoellhofer@web.de
- updated to version 22
  * For systems using GNU libc 2.25 or newer, the version of `explicit_bzero()`
    supplied by the C library is used by default instead of the bundled one.
  * The bundled implementation of `explicit_bzero()` was changed, the old one
    was likely to be inlined by the compiler.
* Mon Jun  5 2017 AxelKoellhofer@web.de
- initial package, version 21
